@@ -4,14 +4,20 @@ import sys, os, math
 
 def python_label():
     v = sys.version_info
-    a = str(v[0]) + "." + str(v[1]) + "." + str(v[2])
+    impl = ""
+    try:
+      pypyv = sys.pypy_version_info
+      impl = "pypy"
+      print(pypyv)
+    except:
+      pass
+    a = str(impl)+str(v[0]) + "." + str(v[1]) + "." + str(v[2])
     print(a)
     return a
 
 
 def update_path():
-    return [os.path.abspath(os.path.join(os.pardir, python_label()))] + [os.getcwd()] + sys.path
-
+    return  [os.path.abspath(os.path.join(os.pardir, python_label()))] + [os.getcwd()] + sys.path
 
 def COMPARE_ASCII_FILES(f1, f2):
     file1 = open(f1)
