@@ -1,21 +1,21 @@
 // -*- C++ -*-
 //
 // This file is part of HepMC
-// Copyright (C) 2014-2019 The HepMC collaboration (see AUTHORS for details)
+// Copyright (C) 2014-2020 The HepMC collaboration (see AUTHORS for details)
 //
 /**
  *  @file GenEvent.cc
  *  @brief Implementation of \b class GenEvent
  *
  */
+#include <deque>
+#include <algorithm> // sort
+
 #include "HepMC3/GenEvent.h"
 #include "HepMC3/GenParticle.h"
 #include "HepMC3/GenVertex.h"
 #include "HepMC3/Data/GenEventData.h"
 
-#include <deque>
-#include <algorithm> // sort
-
 namespace HepMC3 {
 
 GenEvent::GenEvent(Units::MomentumUnit mu,
@@ -45,9 +45,8 @@ const std::vector<ConstGenVertexPtr>& GenEvent::vertices() const {
 }
 
 
-// void GenEvent::add_particle( const GenParticlePtr &p ) {
-void GenEvent::add_particle( GenParticlePtr p ) {
-    if( !p|| p->in_event() ) return;
+void GenEvent::add_particle(GenParticlePtr p) {
+    if ( !p || p->in_event() ) return;
 
     m_particles.push_back(p);
 
@@ -55,7 +54,7 @@ void GenEvent::add_particle( GenParticlePtr p ) {
     p->m_id = particles().size();
 
     // Particles without production vertex are added to the root vertex
-    if( !p->production_vertex() )
+    if ( !p->production_vertex() )
         m_rootvertex->add_particle_out(p);
 }
 
@@ -73,11 +72,11 @@ GenEvent::GenEvent(const GenEvent&e) {
 }
 
 GenEvent::~GenEvent() {
-    for ( std::map< std::string, std::map<int, std::shared_ptr<Attribute> > >::iterator attm=m_attributes.begin(); attm!=m_attributes.end(); ++attm)
-        for ( std::map<int, std::shared_ptr<Attribute> >::iterator att=attm->second.begin(); att!=attm->second.end(); ++att) if (att->second) att->second->m_event = nullptr;
+    for ( std::map< std::string, std::map<int, std::shared_ptr<Attribute> > >::iterator attm = m_attributes.begin(); attm != m_attributes.end(); ++attm)
+        for ( std::map<int, std::shared_ptr<Attribute> >::iterator att = attm->second.begin(); att != attm->second.end(); ++att) if (att->second) att->second->m_event = nullptr;
 
-    for  ( std::vector<GenVertexPtr>::iterator v=m_vertices.begin(); v!=m_vertices.end(); ++v ) if (*v)  if ((*v)->m_event==this) (*v)->m_event=nullptr;
-    for  ( std::vector<GenParticlePtr>::iterator p=m_particles.begin(); p!=m_particles.end(); ++p ) if (*p)  if ((*p)->m_event==this)  (*p)->m_event=nullptr;
+    for  ( std::vector<GenVertexPtr>::iterator v = m_vertices.begin(); v != m_vertices.end(); ++v ) if (*v)  if ((*v)->m_event == this) (*v)->m_event = nullptr;
+    for  ( std::vector<GenParticlePtr>::iterator p = m_particles.begin(); p != m_particles.end(); ++p ) if (*p)  if ((*p)->m_event == this)  (*p)->m_event = nullptr;
 }
 
 GenEvent& GenEvent::operator=(const GenEvent& e) {
@@ -94,55 +93,55 @@ GenEvent& GenEvent::operator=(const GenEvent& e) {
 }
 
 
-void GenEvent::add_vertex( GenVertexPtr v ) {
-    if( !v|| v->in_event() ) return;
+void GenEvent::add_vertex(GenVertexPtr v) {
+    if ( !v|| v->in_event() ) return;
     m_vertices.push_back(v);
 
     v->m_event = this;
     v->m_id = -(int)vertices().size();
 
     // Add all incoming and outgoing particles and restore their production/end vertices
-    for(auto p: v->particles_in() ) {
-        if(!p->in_event()) add_particle(p);
+    for (auto p: v->particles_in()) {
+        if (!p->in_event()) add_particle(p);
         p->m_end_vertex = v->shared_from_this();
     }
 
-    for(auto p: v->particles_out() ) {
-        if(!p->in_event()) add_particle(p);
+    for (auto p: v->particles_out()) {
+        if (!p->in_event()) add_particle(p);
         p->m_production_vertex = v;
     }
 }
 
 
-void GenEvent::remove_particle( GenParticlePtr p ) {
-    if( !p || p->parent_event() != this ) return;
+void GenEvent::remove_particle(GenParticlePtr p) {
+    if ( !p || p->parent_event() != this ) return;
 
-    HEPMC3_DEBUG( 30, "GenEvent::remove_particle - called with particle: "<<p->id() );
+    HEPMC3_DEBUG(30, "GenEvent::remove_particle - called with particle: " << p->id());
     GenVertexPtr end_vtx = p->end_vertex();
-    if( end_vtx ) {
+    if ( end_vtx ) {
         end_vtx->remove_particle_in(p);
 
         // If that was the only incoming particle, remove vertex from the event
-        if( end_vtx->particles_in().size() == 0 )  remove_vertex(end_vtx);
+        if ( end_vtx->particles_in().size() == 0 )  remove_vertex(end_vtx);
     }
 
     GenVertexPtr prod_vtx = p->production_vertex();
-    if( prod_vtx ) {
+    if ( prod_vtx ) {
         prod_vtx->remove_particle_out(p);
 
         // If that was the only outgoing particle, remove vertex from the event
-        if( prod_vtx->particles_out().size() == 0 ) remove_vertex(prod_vtx);
+        if ( prod_vtx->particles_out().size() == 0 ) remove_vertex(prod_vtx);
     }
 
-    HEPMC3_DEBUG( 30, "GenEvent::remove_particle - erasing particle: " << p->id() )
+    HEPMC3_DEBUG(30, "GenEvent::remove_particle - erasing particle: " << p->id())
 
     int idx = p->id();
-    std::vector<GenParticlePtr>::iterator it = m_particles.erase(m_particles.begin() + idx-1 );
+    std::vector<GenParticlePtr>::iterator it = m_particles.erase(m_particles.begin() + idx-1);
 
     // Remove attributes of this particle
     std::lock_guard<std::recursive_mutex> lock(m_lock_attributes);
     std::vector<std::string> atts = p->attribute_names();
-    for(const std::string &s: atts) {
+    for (const std::string &s: atts) {
         p->remove_attribute(s);
     }
 
@@ -151,22 +150,22 @@ void GenEvent::remove_particle( GenParticlePtr p ) {
     //
     std::vector< std::pair< int, std::shared_ptr<Attribute> > > changed_attributes;
 
-    for(att_key_t& vt1: m_attributes ) {
+    for (att_key_t& vt1: m_attributes) {
         changed_attributes.clear();
 
-        for ( std::map<int, std::shared_ptr<Attribute> >::iterator vt2=vt1.second.begin(); vt2!=vt1.second.end(); ++vt2) {
-            if( (*vt2).first > p->id() ) {
+        for (std::map<int, std::shared_ptr<Attribute> >::iterator vt2 = vt1.second.begin(); vt2 != vt1.second.end(); ++vt2) {
+            if ( (*vt2).first > p->id() ) {
                 changed_attributes.push_back(*vt2);
             }
         }
 
-        for( att_val_t val: changed_attributes ) {
+        for ( att_val_t val: changed_attributes ) {
             vt1.second.erase(val.first);
             vt1.second[val.first-1] = val.second;
         }
     }
     // Reassign id of particles with id above this one
-    for(; it != m_particles.end(); ++it) {
+    for (; it != m_particles.end(); ++it) {
         --((*it)->m_id);
     }
 
@@ -182,26 +181,25 @@ struct sort_by_id_asc {
     }
 };
 
-void GenEvent::remove_particles( std::vector<GenParticlePtr> v ) {
+void GenEvent::remove_particles(std::vector<GenParticlePtr> v) {
+    std::sort(v.begin(), v.end(), sort_by_id_asc());
 
-    std::sort( v.begin(), v.end(), sort_by_id_asc() );
-
-    for (std::vector<GenParticlePtr>::iterator p=v.begin(); p!=v.end(); ++p) {
+    for (std::vector<GenParticlePtr>::iterator p = v.begin(); p != v.end(); ++p) {
         remove_particle(*p);
     }
 }
 
-void GenEvent::remove_vertex( GenVertexPtr v ) {
-    if( !v || v->parent_event() != this ) return;
+void GenEvent::remove_vertex(GenVertexPtr v) {
+    if ( !v || v->parent_event() != this ) return;
 
-    HEPMC3_DEBUG( 30, "GenEvent::remove_vertex   - called with vertex:  "<<v->id() );
+    HEPMC3_DEBUG(30, "GenEvent::remove_vertex   - called with vertex:  " << v->id());
     std::shared_ptr<GenVertex> null_vtx;
 
-    for(auto p: v->particles_in() ) {
+    for (auto p: v->particles_in()) {
         p->m_end_vertex = std::weak_ptr<GenVertex>();
     }
 
-    for(auto p: v->particles_out() ) {
+    for (auto p: v->particles_out()) {
         p->m_production_vertex = std::weak_ptr<GenVertex>();
 
         // recursive delete rest of the tree
@@ -209,14 +207,14 @@ void GenEvent::remove_vertex( GenVertexPtr v ) {
     }
 
     // Erase this vertex from vertices list
-    HEPMC3_DEBUG( 30, "GenEvent::remove_vertex   - erasing vertex: " << v->id() )
+    HEPMC3_DEBUG(30, "GenEvent::remove_vertex   - erasing vertex: " << v->id())
 
     int idx = -v->id();
-    std::vector<GenVertexPtr>::iterator it = m_vertices.erase(m_vertices.begin() + idx-1 );
+    std::vector<GenVertexPtr>::iterator it = m_vertices.erase(m_vertices.begin() + idx-1);
     // Remove attributes of this vertex
     std::lock_guard<std::recursive_mutex> lock(m_lock_attributes);
     std::vector<std::string> atts = v->attribute_names();
-    for(std::string s: atts) {
+    for (std::string s: atts) {
         v->remove_attribute(s);
     }
 
@@ -226,23 +224,23 @@ void GenEvent::remove_vertex( GenVertexPtr v ) {
 
     std::vector< std::pair< int, std::shared_ptr<Attribute> > > changed_attributes;
 
-    for( att_key_t& vt1: m_attributes ) {
+    for ( att_key_t& vt1: m_attributes ) {
         changed_attributes.clear();
 
-        for ( std::map<int, std::shared_ptr<Attribute> >::iterator vt2=vt1.second.begin(); vt2!=vt1.second.end(); ++vt2) {
-            if( (*vt2).first < v->id() ) {
+        for (std::map<int, std::shared_ptr<Attribute> >::iterator vt2 = vt1.second.begin(); vt2 != vt1.second.end(); ++vt2) {
+            if ( (*vt2).first < v->id() ) {
                 changed_attributes.push_back(*vt2);
             }
         }
 
-        for( att_val_t val: changed_attributes ) {
+        for ( att_val_t val: changed_attributes ) {
             vt1.second.erase(val.first);
             vt1.second[val.first+1] = val.second;
         }
     }
 
     // Reassign id of particles with id above this one
-    for(; it != m_vertices.end(); ++it) {
+    for (; it != m_vertices.end(); ++it) {
         ++((*it)->m_id);
     }
 
@@ -252,44 +250,43 @@ void GenEvent::remove_vertex( GenVertexPtr v ) {
 }
 /// @todo This looks dangerously similar to the recusive event traversel that we forbade in the
 ///       Core library due to wories about generator dependence
-static bool visit_children(std::map<ConstGenVertexPtr,int>  &a, ConstGenVertexPtr v)
+static bool visit_children(std::map<ConstGenVertexPtr, int>  &a, ConstGenVertexPtr v)
 {
     for ( ConstGenParticlePtr p: v->particles_out())
         if (p->end_vertex())
         {
-            if (a[p->end_vertex()]!=0) return true;
+            if (a[p->end_vertex()] != 0) return true;
             else a[p->end_vertex()]++;
             if (visit_children(a, p->end_vertex())) return true;
         }
     return false;
 }
 
-void GenEvent::add_tree( const std::vector<GenParticlePtr> &parts ) {
-
-    std::shared_ptr<IntAttribute> existing_hc=attribute<IntAttribute>("cycles");
-    bool has_cycles=false;
-    std::map<GenVertexPtr,int>  sortingv;
+void GenEvent::add_tree(const std::vector<GenParticlePtr> &parts) {
+    std::shared_ptr<IntAttribute> existing_hc = attribute<IntAttribute>("cycles");
+    bool has_cycles = false;
+    std::map<GenVertexPtr, int>  sortingv;
     std::vector<GenVertexPtr> noinv;
-    if (existing_hc)     if (existing_hc->value()!=0) has_cycles=true;
-    if(!existing_hc)
+    if (existing_hc)     if (existing_hc->value() != 0) has_cycles = true;
+    if (!existing_hc)
     {
-        for(GenParticlePtr p: parts ) {
+        for (GenParticlePtr p: parts) {
             GenVertexPtr v = p->production_vertex();
-            if(v) sortingv[v]=0;
-            if( !v || v->particles_in().size()==0 ) {
+            if (v) sortingv[v]=0;
+            if ( !v || v->particles_in().size() == 0 ) {
                 GenVertexPtr v2 = p->end_vertex();
-                if(v2) {noinv.push_back(v2); sortingv[v2]=0;}
+                if (v2) {noinv.push_back(v2); sortingv[v2] = 0;}
             }
         }
         for (GenVertexPtr v: noinv) {
-            std::map<ConstGenVertexPtr,int>  sorting_temp(sortingv.begin(), sortingv.end());
-            has_cycles=(has_cycles||visit_children(sorting_temp, v));
+            std::map<ConstGenVertexPtr, int>  sorting_temp(sortingv.begin(), sortingv.end());
+            has_cycles = (has_cycles || visit_children(sorting_temp, v));
         }
     }
     if (has_cycles) {
         add_attribute("cycles", std::make_shared<IntAttribute>(1));
         /* Commented out  as improvemnts allow us to do sorting in other way.
-         for( std::map<GenVertexPtr,int>::iterator vi=sortingv.begin();vi!=sortingv.end();++vi) if( !vi->first->in_event() ) add_vertex(vi->first);
+         for ( std::map<GenVertexPtr,int>::iterator vi=sortingv.begin();vi!=sortingv.end();++vi) if ( !vi->first->in_event() ) add_vertex(vi->first);
          return;
          */
     }
@@ -297,11 +294,11 @@ void GenEvent::add_tree( const std::vector<GenParticlePtr> &parts ) {
     std::deque<GenVertexPtr> sorting;
 
     // Find all starting vertices (end vertex of particles that have no production vertex)
-    for(auto p: parts ) {
+    for (auto p: parts) {
         const GenVertexPtr &v = p->production_vertex();
-        if( !v || v->particles_in().size()==0 ) {
+        if ( !v || v->particles_in().size() == 0 ) {
             const GenVertexPtr &v2 = p->end_vertex();
-            if(v2) sorting.push_back(v2);
+            if (v2) sorting.push_back(v2);
         }
     }
 
@@ -311,9 +308,9 @@ void GenEvent::add_tree( const std::vector<GenParticlePtr> &parts ) {
     )
 
     // Add vertices to the event in topological order
-    while( !sorting.empty() ) {
+    while ( !sorting.empty() ) {
         HEPMC3_DEBUG_CODE_BLOCK(
-            if( sorting.size() > max_deque_size ) max_deque_size = sorting.size();
+            if ( sorting.size() > max_deque_size ) max_deque_size = sorting.size();
             ++sorting_loop_count;
         )
 
@@ -322,9 +319,9 @@ void GenEvent::add_tree( const std::vector<GenParticlePtr> &parts ) {
         bool added = false;
 
         // Add all mothers to the front of the list
-        for( auto p: v->particles_in() ) {
+        for ( auto p: v->particles_in() ) {
             GenVertexPtr v2 = p->production_vertex();
-            if( v2 && !v2->in_event() && find(sorting.begin(),sorting.end(),v2)==sorting.end()) {
+            if ( v2 && !v2->in_event() && find(sorting.begin(), sorting.end(), v2) == sorting.end() ) {
                 sorting.push_front(v2);
                 added = true;
             }
@@ -332,17 +329,16 @@ void GenEvent::add_tree( const std::vector<GenParticlePtr> &parts ) {
 
         // If we have added at least one production vertex,
         // our vertex is not the first one on the list
-        if( added ) continue;
+        if ( added ) continue;
 
         // If vertex not yet added
-        if( !v->in_event() ) {
-
+        if ( !v->in_event() ) {
             add_vertex(v);
 
             // Add all end vertices to the end of the list
-            for(auto p: v->particles_out() ) {
+            for (auto p: v->particles_out()) {
                 GenVertexPtr v2 = p->end_vertex();
-                if( v2 && !v2->in_event()&& find(sorting.begin(),sorting.end(),v2)==sorting.end() ) {
+                if ( v2 && !v2->in_event()&& find(sorting.begin(), sorting.end(), v2) == sorting.end() ) {
                     sorting.push_back(v2);
                 }
             }
@@ -355,15 +351,15 @@ void GenEvent::add_tree( const std::vector<GenParticlePtr> &parts ) {
     if ( m_rootvertex->id() != 0 ) {
         const int vx = -1 - m_rootvertex->id();
         const int rootid = m_rootvertex->id();
-        if ( vx >= 0 && vx < m_vertices.size() && m_vertices[vx] == m_rootvertex ) {
+        if ( vx >= 0 && vx < (int) m_vertices.size() && m_vertices[vx] == m_rootvertex ) {
             auto next = m_vertices.erase(m_vertices.begin() + vx);
             std::lock_guard<std::recursive_mutex> lock(m_lock_attributes);
-            for(auto & vt1: m_attributes ) {
+            for (auto & vt1: m_attributes) {
                 std::vector< std::pair< int, std::shared_ptr<Attribute> > > changed_attributes;
                 for ( auto vt2 : vt1.second )
-                    if( vt2.first <= rootid )
+                    if ( vt2.first <= rootid )
                         changed_attributes.push_back(vt2);
-                for( auto val : changed_attributes ) {
+                for ( auto val : changed_attributes ) {
                     vt1.second.erase(val.first);
                     vt1.second[val.first == rootid? 0: val.first + 1] = val.second;
                 }
@@ -373,14 +369,14 @@ void GenEvent::add_tree( const std::vector<GenParticlePtr> &parts ) {
                 ++((*next++)->m_id);
             }
         } else {
-            HEPMC3_WARNING( "ReaderAsciiHepMC2: Suspicious looking rootvertex found. Will try to cope." )
+            HEPMC3_WARNING("ReaderAsciiHepMC2: Suspicious looking rootvertex found. Will try to cope.")
         }
     }
 
     HEPMC3_DEBUG_CODE_BLOCK(
-        HEPMC3_DEBUG( 6, "GenEvent - particles sorted: "
-                      <<this->particles().size()<<", max deque size: "
-                      <<max_deque_size<<", iterations: "<<sorting_loop_count )
+        HEPMC3_DEBUG(6, "GenEvent - particles sorted: "
+                     << this->particles().size() << ", max deque size: "
+                     << max_deque_size << ", iterations: " << sorting_loop_count)
     )
     return;
 }
@@ -392,20 +388,20 @@ void GenEvent::reserve(const size_t& parts, const size_t& verts) {
 }
 
 
-void GenEvent::set_units( Units::MomentumUnit new_momentum_unit, Units::LengthUnit new_length_unit) {
-    if( new_momentum_unit != m_momentum_unit ) {
-        for( GenParticlePtr p: m_particles ) {
-            Units::convert( p->m_data.momentum, m_momentum_unit, new_momentum_unit );
-            Units::convert( p->m_data.mass, m_momentum_unit, new_momentum_unit );
+void GenEvent::set_units(Units::MomentumUnit new_momentum_unit, Units::LengthUnit new_length_unit) {
+    if ( new_momentum_unit != m_momentum_unit ) {
+        for ( GenParticlePtr p: m_particles ) {
+            Units::convert(p->m_data.momentum, m_momentum_unit, new_momentum_unit);
+            Units::convert(p->m_data.mass, m_momentum_unit, new_momentum_unit);
         }
 
         m_momentum_unit = new_momentum_unit;
     }
 
-    if( new_length_unit != m_length_unit ) {
-        for(GenVertexPtr &v: m_vertices ) {
+    if ( new_length_unit != m_length_unit ) {
+        for (GenVertexPtr &v: m_vertices) {
             FourVector &fv = v->m_data.position;
-            if( !fv.is_zero() ) Units::convert( fv, m_length_unit, new_length_unit );
+            if ( !fv.is_zero() ) Units::convert( fv, m_length_unit, new_length_unit );
         }
 
         m_length_unit = new_length_unit;
@@ -425,97 +421,96 @@ const std::vector<GenParticlePtr> & GenEvent::beams() {
     return m_rootvertex->particles_out();
 }
 
-void GenEvent::shift_position_by( const FourVector & delta ) {
-    m_rootvertex->set_position( event_pos() + delta );
+void GenEvent::shift_position_by(const FourVector & delta) {
+    m_rootvertex->set_position(event_pos() + delta);
 
     // Offset all vertices
     for ( GenVertexPtr v: m_vertices ) {
         if ( v->has_set_position() )
-            v->set_position( v->position() + delta );
+            v->set_position(v->position() + delta);
     }
 }
 
-bool GenEvent::rotate( const FourVector&  delta )
+bool GenEvent::rotate(const FourVector&  delta)
 {
-
     for ( auto p: m_particles)
     {
-        FourVector mom=p->momentum();
-        long double tempX=mom.x();
-        long double tempY=mom.y();
-        long double tempZ=mom.z();
+        FourVector mom = p->momentum();
+        long double tempX = mom.x();
+        long double tempY = mom.y();
+        long double tempZ = mom.z();
 
         long double tempX_;
         long double tempY_;
         long double tempZ_;
 
 
-        long double cosa=cos(delta.x());
-        long double sina=sin(delta.x());
+        long double cosa = std::cos(delta.x());
+        long double sina = std::sin(delta.x());
 
-        tempY_= cosa*tempY+sina*tempZ;
-        tempZ_=-sina*tempY+cosa*tempZ;
-        tempY=tempY_;
-        tempZ=tempZ_;
+        tempY_ = cosa*tempY+sina*tempZ;
+        tempZ_ = -sina*tempY+cosa*tempZ;
+        tempY = tempY_;
+        tempZ = tempZ_;
 
 
-        long double cosb=cos(delta.y());
-        long double sinb=sin(delta.y());
+        long double cosb = std::cos(delta.y());
+        long double sinb = std::sin(delta.y());
 
-        tempX_= cosb*tempX-sinb*tempZ;
-        tempZ_= sinb*tempX+cosb*tempZ;
-        tempX=tempX_;
-        tempZ=tempZ_;
+        tempX_ = cosb*tempX-sinb*tempZ;
+        tempZ_ = sinb*tempX+cosb*tempZ;
+        tempX = tempX_;
+        tempZ = tempZ_;
 
-        long double cosg=cos(delta.z());
-        long double sing=sin(delta.z());
+        long double cosg = std::cos(delta.z());
+        long double sing = std::sin(delta.z());
 
-        tempX_= cosg*tempX+sing*tempY;
-        tempY_=-sing*tempX+cosg*tempY;
-        tempX=tempX_;
-        tempY=tempY_;
+        tempX_ = cosg*tempX+sing*tempY;
+        tempY_ = -sing*tempX+cosg*tempY;
+        tempX = tempX_;
+        tempY = tempY_;
 
-        FourVector temp(tempX,tempY,tempZ,mom.e());
+        FourVector temp(tempX, tempY, tempZ, mom.e());
         p->set_momentum(temp);
     }
-    for ( auto v: m_vertices)
+    for (auto v: m_vertices)
     {
-        FourVector pos=v->position();
-        long double tempX=pos.x();
-        long double tempY=pos.y();
-        long double tempZ=pos.z();
+        FourVector pos = v->position();
+        long double tempX = pos.x();
+        long double tempY = pos.y();
+        long double tempZ = pos.z();
 
         long double tempX_;
         long double tempY_;
         long double tempZ_;
 
 
-        long double cosa=cos(delta.x());
-        long double sina=sin(delta.x());
+        long double cosa = std::cos(delta.x());
+        long double sina = std::sin(delta.x());
 
-        tempY_= cosa*tempY+sina*tempZ;
-        tempZ_=-sina*tempY+cosa*tempZ;
-        tempY=tempY_;
-        tempZ=tempZ_;
+        tempY_ = cosa*tempY+sina*tempZ;
+        tempZ_ = -sina*tempY+cosa*tempZ;
+        tempY = tempY_;
+        tempZ = tempZ_;
 
 
-        long double cosb=cos(delta.y());
-        long double sinb=sin(delta.y());
+        long double cosb = std::cos(delta.y());
+        long double sinb = std::sin(delta.y());
 
-        tempX_= cosb*tempX-sinb*tempZ;
-        tempZ_= sinb*tempX+cosb*tempZ;
-        tempX=tempX_;
-        tempZ=tempZ_;
+        tempX_ = cosb*tempX-sinb*tempZ;
+        tempZ_ = sinb*tempX+cosb*tempZ;
+        tempX = tempX_;
+        tempZ = tempZ_;
 
-        long double cosg=cos(delta.z());
-        long double sing=sin(delta.z());
+        long double cosg = std::cos(delta.z());
+        long double sing = std::sin(delta.z());
 
-        tempX_= cosg*tempX+sing*tempY;
-        tempY_=-sing*tempX+cosg*tempY;
-        tempX=tempX_;
-        tempY=tempY_;
+        tempX_ = cosg*tempX+sing*tempY;
+        tempY_ = -sing*tempX+cosg*tempY;
+        tempX = tempX_;
+        tempY = tempY_;
 
-        FourVector temp(tempX,tempY,tempZ,pos.t());
+        FourVector temp(tempX, tempY, tempZ, pos.t());
         v->set_position(temp);
     }
 
@@ -525,28 +520,28 @@ bool GenEvent::rotate( const FourVector&  delta )
 
 bool GenEvent::reflect(const int axis)
 {
-    if (axis>3||axis<0)
+    if ( axis > 3 || axis < 0 )
     {
-        HEPMC3_WARNING( "GenEvent::reflect: wrong axis" )
+        HEPMC3_WARNING("GenEvent::reflect: wrong axis")
         return false;
     }
     switch (axis)
     {
     case 0:
-        for ( auto p: m_particles) { FourVector temp=p->momentum(); temp.setX(-p->momentum().x()); p->set_momentum(temp);}
-        for ( auto v: m_vertices)  { FourVector temp=v->position(); temp.setX(-v->position().x()); v->set_position(temp);}
+        for ( auto p: m_particles) { FourVector temp = p->momentum(); temp.setX(-p->momentum().x()); p->set_momentum(temp);}
+        for ( auto v: m_vertices)  { FourVector temp = v->position(); temp.setX(-v->position().x()); v->set_position(temp);}
         break;
     case 1:
-        for ( auto p: m_particles) { FourVector temp=p->momentum(); temp.setY(-p->momentum().y()); p->set_momentum(temp);}
-        for ( auto v: m_vertices)  { FourVector temp=v->position(); temp.setY(-v->position().y()); v->set_position(temp);}
+        for ( auto p: m_particles) { FourVector temp = p->momentum(); temp.setY(-p->momentum().y()); p->set_momentum(temp);}
+        for ( auto v: m_vertices)  { FourVector temp = v->position(); temp.setY(-v->position().y()); v->set_position(temp);}
         break;
     case 2:
-        for ( auto p: m_particles) { FourVector temp=p->momentum(); temp.setZ(-p->momentum().z()); p->set_momentum(temp);}
-        for ( auto v: m_vertices)  { FourVector temp=v->position(); temp.setZ(-v->position().z()); v->set_position(temp);}
+        for ( auto p: m_particles) { FourVector temp = p->momentum(); temp.setZ(-p->momentum().z()); p->set_momentum(temp);}
+        for ( auto v: m_vertices)  { FourVector temp = v->position(); temp.setZ(-v->position().z()); v->set_position(temp);}
         break;
     case 3:
-        for ( auto p: m_particles) { FourVector temp=p->momentum(); temp.setT(-p->momentum().e()); p->set_momentum(temp);}
-        for ( auto v: m_vertices)  { FourVector temp=v->position(); temp.setT(-v->position().t()); v->set_position(temp);}
+        for ( auto p: m_particles) { FourVector temp = p->momentum(); temp.setT(-p->momentum().e()); p->set_momentum(temp);}
+        for ( auto v: m_vertices)  { FourVector temp = v->position(); temp.setT(-v->position().t()); v->set_position(temp);}
         break;
     default:
         return false;
@@ -555,56 +550,52 @@ bool GenEvent::reflect(const int axis)
     return true;
 }
 
-bool GenEvent::boost( const FourVector&  delta )
+bool GenEvent::boost(const FourVector&  delta)
 {
-
-    double deltalength2d=delta.length2();
-    if (deltalength2d>1.0)
+    double deltalength2d = delta.length2();
+    if (deltalength2d > 1.0)
     {
-        HEPMC3_WARNING( "GenEvent::boost: wrong large boost vector. Will leave event as is." )
+        HEPMC3_WARNING("GenEvent::boost: wrong large boost vector. Will leave event as is.")
         return false;
     }
-    if (std::abs(deltalength2d-1.0)<std::numeric_limits<double>::epsilon())
+    if (std::abs(deltalength2d-1.0) < std::numeric_limits<double>::epsilon())
     {
-        HEPMC3_WARNING( "GenEvent::boost: too large gamma. Will leave event as is." )
+        HEPMC3_WARNING("GenEvent::boost: too large gamma. Will leave event as is.")
         return false;
     }
-    if (std::abs(deltalength2d)<std::numeric_limits<double>::epsilon())
+    if (std::abs(deltalength2d) < std::numeric_limits<double>::epsilon())
     {
-        HEPMC3_WARNING( "GenEvent::boost: wrong small boost vector. Will leave event as is." )
+        HEPMC3_WARNING("GenEvent::boost: wrong small boost vector. Will leave event as is.")
         return true;
     }
-    long double deltaX=delta.x();
-    long double deltaY=delta.y();
-    long double deltaZ=delta.z();
-    long double deltalength2=deltaX*deltaX+deltaY*deltaY+deltaZ*deltaZ;
-    long double deltalength=std::sqrt(deltalength2 );
-    long double gamma=1.0/std::sqrt(1.0-deltalength2);
+    long double deltaX = delta.x();
+    long double deltaY = delta.y();
+    long double deltaZ = delta.z();
+    long double deltalength2 = deltaX*deltaX+deltaY*deltaY+deltaZ*deltaZ;
+    long double deltalength = std::sqrt(deltalength2);
+    long double gamma = 1.0/std::sqrt(1.0-deltalength2);
 
     for ( auto p: m_particles)
     {
-        FourVector mom=p->momentum();
+        FourVector mom = p->momentum();
 
-        long double tempX=mom.x();
-        long double tempY=mom.y();
-        long double tempZ=mom.z();
-        long double tempE=mom.e();
-        long double nr=(deltaX*tempX+deltaY*tempY+deltaZ*tempZ)/deltalength;
+        long double tempX = mom.x();
+        long double tempY = mom.y();
+        long double tempZ = mom.z();
+        long double tempE = mom.e();
+        long double nr = (deltaX*tempX+deltaY*tempY+deltaZ*tempZ)/deltalength;
 
         tempX+=(deltaX*((gamma-1)*nr/deltalength)-deltaX*(tempE*gamma));
         tempY+=(deltaY*((gamma-1)*nr/deltalength)-deltaY*(tempE*gamma));
         tempZ+=(deltaZ*((gamma-1)*nr/deltalength)-deltaZ*(tempE*gamma));
-        tempE=gamma*(tempE-deltalength*nr);
-        FourVector temp(tempX,tempY,tempZ,tempE);
+        tempE = gamma*(tempE-deltalength*nr);
+        FourVector temp(tempX, tempY, tempZ, tempE);
         p->set_momentum(temp);
     }
 
     return true;
 }
 
-
-
-
 void GenEvent::clear() {
     std::lock_guard<std::recursive_mutex> lock(m_lock_attributes);
     m_event_number = 0;
@@ -615,27 +606,24 @@ void GenEvent::clear() {
     m_vertices.clear();
 }
 
-
-
-
 void GenEvent::remove_attribute(const std::string &name,  const int& id) {
     std::lock_guard<std::recursive_mutex> lock(m_lock_attributes);
     std:: map< std::string, std::map<int, std::shared_ptr<Attribute> > >::iterator i1 =
         m_attributes.find(name);
-    if( i1 == m_attributes.end() ) return;
+    if ( i1 == m_attributes.end() ) return;
 
     std::map<int, std::shared_ptr<Attribute> >::iterator i2 = i1->second.find(id);
-    if( i2 == i1->second.end() ) return;
+    if ( i2 == i1->second.end() ) return;
 
     i1->second.erase(i2);
 }
 
-std::vector<std::string> GenEvent::attribute_names( const int& id) const {
+std::vector<std::string> GenEvent::attribute_names(const int& id) const {
     std::vector<std::string> results;
 
-    for(const att_key_t& vt1: m_attributes ) {
-        if( vt1.second.count( id ) == 1 ) {
-            results.push_back( vt1.first );
+    for (const att_key_t& vt1: m_attributes) {
+        if ( vt1.second.count(id) == 1 ) {
+            results.push_back(vt1.first);
         }
     }
 
@@ -644,13 +632,13 @@ std::vector<std::string> GenEvent::attribute_names( const int& id) const {
 
 void GenEvent::write_data(GenEventData& data) const {
     // Reserve memory for containers
-    data.particles.reserve( this->particles().size() );
-    data.vertices.reserve( this->vertices().size() );
-    data.links1.reserve( this->particles().size()*2 );
-    data.links2.reserve( this->particles().size()*2 );
-    data.attribute_id.reserve( m_attributes.size() );
-    data.attribute_name.reserve( m_attributes.size() );
-    data.attribute_string.reserve( m_attributes.size() );
+    data.particles.reserve(this->particles().size());
+    data.vertices.reserve(this->vertices().size());
+    data.links1.reserve(this->particles().size()*2);
+    data.links2.reserve(this->particles().size()*2);
+    data.attribute_id.reserve(m_attributes.size());
+    data.attribute_name.reserve(m_attributes.size());
+    data.attribute_string.reserve(m_attributes.size());
 
     // Fill event data
     data.event_number  = this->event_number();
@@ -661,34 +649,33 @@ void GenEvent::write_data(GenEventData& data) const {
     // Fill containers
     data.weights = this->weights();
 
-    for( ConstGenParticlePtr p: this->particles() ) {
-        data.particles.push_back( p->data() );
+    for (ConstGenParticlePtr p: this->particles()) {
+        data.particles.push_back(p->data());
     }
 
-    for(ConstGenVertexPtr v: this->vertices() ) {
-        data.vertices.push_back( v->data() );
+    for (ConstGenVertexPtr v: this->vertices()) {
+        data.vertices.push_back(v->data());
         int v_id = v->id();
 
-        for(ConstGenParticlePtr p: v->particles_in() ) {
-            data.links1.push_back( p->id() );
-            data.links2.push_back( v_id    );
+        for (ConstGenParticlePtr p: v->particles_in()) {
+            data.links1.push_back(p->id());
+            data.links2.push_back(v_id);
         }
 
-        for(ConstGenParticlePtr p: v->particles_out() ) {
-            data.links1.push_back( v_id    );
-            data.links2.push_back( p->id() );
+        for (ConstGenParticlePtr p: v->particles_out()) {
+            data.links1.push_back(v_id);
+            data.links2.push_back(p->id());
         }
     }
 
-    for( const att_key_t& vt1: this->attributes() ) {
-        for( const att_val_t& vt2: vt1.second ) {
-
+    for (const att_key_t& vt1: this->attributes()) {
+        for (const att_val_t& vt2: vt1.second) {
             std::string st;
 
             bool status = vt2.second->to_string(st);
 
-            if( !status ) {
-                HEPMC3_WARNING( "GenEvent::write_data: problem serializing attribute: "<<vt1.first )
+            if ( !status ) {
+                HEPMC3_WARNING("GenEvent::write_data: problem serializing attribute: " << vt1.first)
             }
             else {
                 data.attribute_id.push_back(vt2.first);
@@ -702,17 +689,17 @@ void GenEvent::write_data(GenEventData& data) const {
 
 void GenEvent::read_data(const GenEventData &data) {
     this->clear();
-    this->set_event_number( data.event_number );
-//Note: set_units checks the current unit of event, i.e. applicable only for fully constructed event.
-    m_momentum_unit=data.momentum_unit;
-    m_length_unit=data.length_unit;
-    this->shift_position_to( data.event_pos );
+    this->set_event_number(data.event_number);
+    //Note: set_units checks the current unit of event, i.e. applicable only for fully constructed event.
+    m_momentum_unit = data.momentum_unit;
+    m_length_unit = data.length_unit;
+    this->shift_position_to(data.event_pos);
 
     // Fill weights
     this->weights() = data.weights;
 
     // Fill particle information
-    for( const GenParticleData &pd: data.particles ) {
+    for ( const GenParticleData &pd: data.particles ) {
         GenParticlePtr p = std::make_shared<GenParticle>(pd);
 
         m_particles.push_back(p);
@@ -722,7 +709,7 @@ void GenEvent::read_data(const GenEventData &data) {
     }
 
     // Fill vertex information
-    for( const GenVertexData &vd: data.vertices ) {
+    for ( const GenVertexData &vd: data.vertices ) {
         GenVertexPtr v = std::make_shared<GenVertex>(vd);
 
         m_vertices.push_back(v);
@@ -732,7 +719,7 @@ void GenEvent::read_data(const GenEventData &data) {
     }
 
     // Restore links
-    for( unsigned int i=0; i<data.links1.size(); ++i) {
+    for (unsigned int i = 0; i < data.links1.size(); ++i) {
         int id1 = data.links1[i];
         int id2 = data.links2[i];
         /* @note:
@@ -740,7 +727,7 @@ void GenEvent::read_data(const GenEventData &data) {
         (+-)  --  particle has end vertex
         (-+)  --  particle  has production vertex
         */
-        if ( (id1<0&&id2<0)|| (id1>0&&id2>0) )   { HEPMC3_WARNING( "GenEvent::read_data: wrong link: "<<id1<<" "<<id2 ); continue;}
+        if ((id1 < 0 && id2 <0) || (id1 > 0 && id2 > 0))   { HEPMC3_WARNING("GenEvent::read_data: wrong link: " << id1 << " " << id2); continue;}
 
         if ( id1 > 0 ) { m_vertices[ (-id2)-1 ]->add_particle_in ( m_particles[ id1-1 ] ); continue; }
         if ( id1 < 0 ) { m_vertices[ (-id1)-1 ]->add_particle_out( m_particles[ id2-1 ] );   continue; }
@@ -748,26 +735,25 @@ void GenEvent::read_data(const GenEventData &data) {
     for (auto p:  m_particles) if (!p->production_vertex()) m_rootvertex->add_particle_out(p);
 
     // Read attributes
-    for( unsigned int i=0; i<data.attribute_id.size(); ++i) {
-        add_attribute( data.attribute_name[i],
-                       std::make_shared<StringAttribute>(data.attribute_string[i]),
-                       data.attribute_id[i] );
+    for (unsigned int i = 0; i < data.attribute_id.size(); ++i) {
+        add_attribute(data.attribute_name[i],
+                      std::make_shared<StringAttribute>(data.attribute_string[i]),
+                      data.attribute_id[i]);
     }
 }
 
 
-
 //
 // Deprecated functions
 //
 
-void GenEvent::add_particle( GenParticle *p ) {
-    add_particle( GenParticlePtr(p) );
+void GenEvent::add_particle(GenParticle *p) {
+    add_particle(GenParticlePtr(p));
 }
 
 
-void GenEvent::add_vertex( GenVertex *v ) {
-    add_vertex( GenVertexPtr(v) );
+void GenEvent::add_vertex(GenVertex *v) {
+    add_vertex(GenVertexPtr(v));
 }
 
 
@@ -782,13 +768,13 @@ void GenEvent::add_beam_particle(GenParticlePtr p1) {
         HEPMC3_WARNING("Attempting to add an empty particle as beam particle. Ignored.")
         return;
     }
-    if( p1->in_event()) if (p1->parent_event()!=this)
+    if (p1->in_event()) if (p1->parent_event() != this)
         {
             HEPMC3_WARNING("Attempting to add particle from another event. Ignored.")
             return;
         }
     if (p1->production_vertex())  p1->production_vertex()->remove_particle_out(p1);
-//Particle w/o production vertex is added to root vertex.
+    //Particle w/o production vertex is added to root vertex.
     add_particle(p1);
     p1->set_status(4);
     return;
@@ -799,7 +785,7 @@ std::string GenEvent::attribute_as_string(const std::string &name, const int& id
     std::lock_guard<std::recursive_mutex> lock(m_lock_attributes);
     std::map< std::string, std::map<int, std::shared_ptr<Attribute> > >::iterator i1 =
         m_attributes.find(name);
-    if( i1 == m_attributes.end() ) {
+    if ( i1 == m_attributes.end() ) {
         if ( id == 0 && run_info() ) {
             return run_info()->attribute_as_string(name);
         }
@@ -809,7 +795,7 @@ std::string GenEvent::attribute_as_string(const std::string &name, const int& id
     std::map<int, std::shared_ptr<Attribute> >::iterator i2 = i1->second.find(id);
     if (i2 == i1->second.end() ) return std::string();
 
-    if( !i2->second ) return std::string();
+    if ( !i2->second ) return std::string();
 
     std::string ret;
     i2->second->to_string(ret);
